@@ -7,3 +7,5 @@ from .read_pkl import read_pkl
 from .read_json import read_json
 from .read_nc_moist import read_nc_moist
 from .from_emso import from_emso
+from .from_erddap import from_erddap
+from .read_df import read_df
