@@ -1,6 +1,6 @@
 """ Implementation of util """
 from .concat import concat
-from .iplot import iplot_location, iplot_timeseries
+from .iplot import iplot_location, iplot_timeseries, iplot_line
 from .md5 import md5
 from .es_create_indexes import es_create_indexes
 from .emso import EMSO
